@@ -56,7 +56,7 @@ class HeaderToLabelMiddleware(object):
         self._request_start_time = self.__get_time_in_milliseconds()
         log_label_request_settings = getattr(settings, LOG_LABEL_REQUEST_SETTING, dict())
 
-        nim_headers = Utils.get_raw_nim_headers(request)
+        nim_headers = Utils.get_nim_headers(request)
 
         log_entry_info = dict(
             type=self._REQUEST,
@@ -83,11 +83,11 @@ class HeaderToLabelMiddleware(object):
             log_entry_info[label] = header_value
             log_entry_debug[label] = header_value
 
-        logger.debug('', log_entry_debug)
-        logger.info('', log_entry_info)
+        logger.debug('', extra=log_entry_debug)
+        logger.info('', extra=log_entry_info)
 
     def process_response(self, request, response):
-        nim_headers = Utils.get_raw_nim_headers(request)
+        nim_headers = Utils.get_nim_headers(request)
         log_entry = dict(
             type=self._RESPONSE,
             request_start_time_ms=self._request_start_time,
@@ -132,7 +132,7 @@ class HeaderToLabelMiddleware(object):
         return response
 
     def process_exception(self, request, exception):
-        nim_headers = Utils.get_raw_nim_headers(request)
+        nim_headers = Utils.get_nim_headers(request)
         log_entry = dict(
             type=self._ERROR,
             request_start_time_ms=self._request_start_time,
